@@ -47,12 +47,10 @@
 #define W(x) GTK_WIDGET(gtk_builder_get_object(builder, x))
 
 enum {
-	PAGE_INTRO,
 	PAGE_SEARCH,
 	PAGE_CONNECTING,
 	PAGE_SETUP,
 	PAGE_SSP_SETUP,
-	PAGE_FAILURE,
 	PAGE_FINISHING,
 	PAGE_SUMMARY
 };
@@ -79,13 +77,12 @@ static char *pincode = NULL;
 static GtkBuilder *builder = NULL;
 
 static GtkAssistant *window_assistant = NULL;
-static GtkWidget *button_close = NULL;
+static GtkWidget *button_quit = NULL;
 static GtkWidget *button_cancel = NULL;
 static GtkWidget *page_search = NULL;
 static GtkWidget *page_connecting = NULL;
 static GtkWidget *page_setup = NULL;
 static GtkWidget *page_ssp_setup = NULL;
-static GtkWidget *page_failure = NULL;
 static GtkWidget *page_finishing = NULL;
 static GtkWidget *page_summary = NULL;
 
@@ -100,11 +97,10 @@ static GtkWidget *label_ssp_pin = NULL;
 static GtkWidget *does_not_match_button = NULL;
 static GtkWidget *matches_button = NULL;
 
-static GtkWidget *label_failure = NULL;
-
 static GtkWidget *label_finishing = NULL;
 static GtkWidget *spinner_finishing = NULL;
 
+static gboolean   summary_failure = FALSE;
 static GtkWidget *label_summary = NULL;
 static GtkWidget *extra_config_vbox = NULL;
 
@@ -120,7 +116,7 @@ static GtkWidget *radio_custom = NULL;
 static GtkWidget *entry_custom = NULL;
 
 /* Signals */
-void close_callback(GtkWidget *assistant, gpointer data);
+void quit_callback(GtkWidget *assistant, gpointer data);
 void prepare_callback(GtkWidget *assistant, GtkWidget *page, gpointer data);
 void select_device_changed(BluetoothChooser *selector, const char *address, gpointer user_data);
 gboolean entry_custom_event(GtkWidget *entry, GdkEventKey *event);
@@ -137,7 +133,7 @@ set_large_label (GtkLabel *label, const char *text)
 {
 	char *str;
 
-	str = g_strdup_printf("<span font_desc=\"50\" color=\"black\" bgcolor=\"white\">  %s  </span>", text);
+	str = g_strdup_printf("<span font_desc=\"50\">  %s  </span>", text);
 	gtk_label_set_markup(GTK_LABEL(label), str);
 	g_free(str);
 }
@@ -179,6 +175,7 @@ restart_button_clicked (GtkButton *button,
 	target_address = NULL;
 	g_free (target_name);
 	target_name = NULL;
+	summary_failure = FALSE;
 
 	g_object_set (selector,
 		      "device-category-filter", BLUETOOTH_CATEGORY_NOT_PAIRED_OR_TRUSTED,
@@ -195,14 +192,15 @@ does_not_match_cb (GtkButton *button,
 	GError *error = NULL;
 	char *text;
 
-	gtk_assistant_set_current_page (window_assistant, PAGE_FAILURE);
+	summary_failure = TRUE;
+	gtk_assistant_set_current_page (window_assistant, PAGE_SUMMARY);
 
 	/* translators:
 	 * The '%s' is the device name, for example:
 	 * Pairing with 'Sony Bluetooth Headset' cancelled
 	 */
 	text = g_strdup_printf(_("Pairing with '%s' cancelled"), target_name);
-	gtk_label_set_text(GTK_LABEL(label_failure), text);
+	gtk_label_set_text(GTK_LABEL(label_summary), text);
 	g_free(text);
 
 	invocation = g_object_get_data (G_OBJECT (button), "invocation");
@@ -317,14 +315,15 @@ cancel_callback (GDBusMethodInvocation *invocation,
 
 	create_started = FALSE;
 
-	gtk_assistant_set_current_page (window_assistant, PAGE_FAILURE);
+	summary_failure = TRUE;
+	gtk_assistant_set_current_page (window_assistant, PAGE_SUMMARY);
 
 	/* translators:
 	 * The '%s' is the device name, for example:
 	 * Pairing with 'Sony Bluetooth Headset' cancelled
 	 */
 	text = g_strdup_printf(_("Pairing with '%s' cancelled"), target_name);
-	gtk_label_set_text(GTK_LABEL(label_failure), text);
+	gtk_label_set_text(GTK_LABEL(label_summary), text);
 	g_free(text);
 
 	g_dbus_method_invocation_return_value (invocation, NULL);
@@ -376,7 +375,8 @@ create_callback (BluetoothClient *_client,
 	if (path == NULL) {
 		char *text;
 
-		gtk_assistant_set_current_page (window_assistant, PAGE_FAILURE);
+		summary_failure = TRUE;
+		gtk_assistant_set_current_page (window_assistant, PAGE_SUMMARY);
 
 		/* translators:
 		 * The '%s' is the device name, for example:
@@ -386,7 +386,7 @@ create_callback (BluetoothClient *_client,
 
 		g_warning ("Setting up '%s' failed: %s", target_name, error->message);
 
-		gtk_label_set_markup(GTK_LABEL(label_failure), text);
+		gtk_label_set_markup(GTK_LABEL(label_summary), text);
 		g_free (text);
 
 		return;
@@ -403,13 +403,10 @@ create_callback (BluetoothClient *_client,
 }
 
 void
-close_callback (GtkWidget *assistant,
+quit_callback (GtkWidget *widget,
 		gpointer data)
 {
-	gtk_widget_destroy(assistant);
-
-	//FIXME doesn't work with a GtkApplication
-	gtk_main_quit();
+	gtk_widget_destroy(GTK_WIDGET (window_assistant));
 }
 
 void prepare_callback (GtkWidget *assistant,
@@ -418,7 +415,7 @@ void prepare_callback (GtkWidget *assistant,
 {
 	gboolean complete = TRUE;
 
-	gtk_widget_hide (button_close);
+	gtk_widget_hide (button_quit);
 	gtk_widget_hide (button_cancel);
 
 	if (page == page_search) {
@@ -506,12 +503,12 @@ void prepare_callback (GtkWidget *assistant,
 		gtk_label_set_text (GTK_LABEL (label_finishing), text);
 		g_free (text);
 
-		gtk_widget_show (button_close);
+		gtk_widget_show (button_quit);
 	} else {
 		gtk_spinner_stop (GTK_SPINNER (spinner_finishing));
 	}
 
-	if (page == page_summary) {
+	if (page == page_summary && summary_failure == FALSE) {
 		GList *widgets = NULL;
 		GValue value = { 0, };
 		char **uuids, *text;
@@ -545,13 +542,14 @@ void prepare_callback (GtkWidget *assistant,
 			g_list_free (widgets);
 			gtk_widget_show_all (extra_config_vbox);
 		}
+		gtk_widget_show (button_quit);
 	}
 
 	/* Setup the buttons some */
-	if (page == page_failure) {
+	if (page == page_summary && summary_failure) {
 		complete = FALSE;
 		gtk_assistant_add_action_widget (GTK_ASSISTANT (assistant), W("restart_button"));
-		gtk_widget_show (button_close);
+		gtk_widget_show (button_quit);
 	} else {
 		if (gtk_widget_get_parent (W("restart_button")) != NULL)
 			gtk_assistant_remove_action_widget (GTK_ASSISTANT (assistant), W("restart_button"));
@@ -748,7 +746,7 @@ page_func (gint current_page,
 	return current_page + 1;
 }
 
-static GtkAssistant *
+static gboolean
 create_wizard (void)
 {
 	GtkAssistant *assistant;
@@ -759,20 +757,21 @@ create_wizard (void)
 		if (gtk_builder_add_from_file (builder, PKGDATADIR "/wizard.ui", &err) == 0) {
 			g_warning ("Could not load UI from %s: %s", PKGDATADIR "/wizard.ui", err->message);
 			g_error_free(err);
-			return NULL;
+			return FALSE;
 		}
 	}
 
-	assistant = GTK_ASSISTANT(gtk_builder_get_object(builder, "assistant"));
+	window_assistant = GTK_ASSISTANT(gtk_builder_get_object(builder, "assistant"));
+	assistant = window_assistant;
 
 	gtk_assistant_set_forward_page_func (assistant, page_func, NULL, NULL);
 
 	/* The 2 custom buttons */
-	button_close = W("close_button");
+	button_quit = W("quit_button");
 	button_cancel = W("cancel_button");
-	gtk_assistant_add_action_widget (assistant, button_close);
+	gtk_assistant_add_action_widget (assistant, button_quit);
 	gtk_assistant_add_action_widget (assistant, button_cancel);
-	gtk_widget_hide (button_close);
+	gtk_widget_hide (button_quit);
 	gtk_widget_hide (button_cancel);
 
 	/* Intro page, nothing to do */
@@ -799,11 +798,6 @@ create_wizard (void)
 	does_not_match_button = W("does_not_match_button");
 	matches_button = W("matches_button");
 
-	/* Failure page */
-	page_failure = W("page_failure");
-	gtk_assistant_set_page_complete(assistant, page_failure, FALSE);
-	label_failure = W("label_failure");
-
 	/* Finishing page */
 	page_finishing = W("page_finishing");
 	label_finishing = W("label_finishing");
@@ -838,7 +832,7 @@ create_wizard (void)
 
 	gtk_assistant_update_buttons_state(GTK_ASSISTANT(assistant));
 
-	return assistant;
+	return TRUE;
 }
 
 static void
@@ -901,8 +895,7 @@ int main (int argc, char **argv)
 
 	bluetooth_plugin_manager_init ();
 
-	window_assistant = create_wizard();
-	if (window_assistant == NULL)
+	if (create_wizard() == FALSE)
 		return 1;
 	gtk_application_add_window (app,
 				    GTK_WINDOW (window_assistant));
